@@ -1,22 +1,8 @@
 /*
  * This file is part of the KDE Milou Project
- * Copyright (C) 2019 Kai Uwe Broulik <kde@broulik.de>
+ * SPDX-FileCopyrightText: 2019 Kai Uwe Broulik <kde@broulik.de>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) version 3, or any
- * later version accepted by the membership of KDE e.V. (or its
- * successor approved by the membership of KDE e.V.), which shall
- * act as a proxy defined in Section 6 of version 3 of the license.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  *
  */
 
@@ -30,6 +16,7 @@
 #include <KDescendantsProxyModel>
 #include <KModelIndexProxyMapper>
 
+#include <KRunner/AbstractRunner>
 #include <cmath>
 
 using namespace Milou;
@@ -306,7 +293,7 @@ public:
 
     ResultsModel *q;
 
-    QString runner;
+    QPointer<Plasma::AbstractRunner> runner = nullptr;
 
     RunnerResultsModel *resultsModel;
     SortProxyModel *sortModel;
@@ -333,7 +320,6 @@ ResultsModel::ResultsModel(QObject *parent)
 {
     connect(d->resultsModel, &RunnerResultsModel::queryStringChanged, this, &ResultsModel::queryStringChanged);
     connect(d->resultsModel, &RunnerResultsModel::queryingChanged, this, &ResultsModel::queryingChanged);
-    connect(d->resultsModel, &RunnerResultsModel::runnerChanged, this, &ResultsModel::runnerChanged);
     connect(d->resultsModel, &RunnerResultsModel::queryStringChangeRequested, this, &ResultsModel::queryStringChangeRequested);
 
     connect(d->resultsModel, &RunnerResultsModel::queryStringChanged, d->sortModel, &SortProxyModel::setQueryString);
@@ -371,7 +357,7 @@ QString ResultsModel::queryString() const
 
 void ResultsModel::setQueryString(const QString &queryString)
 {
-    d->resultsModel->setQueryString(queryString);
+    d->resultsModel->setQueryString(queryString, runner());
 }
 
 int ResultsModel::limit() const
@@ -396,22 +382,30 @@ bool ResultsModel::querying() const
 
 QString ResultsModel::runner() const
 {
-    return d->resultsModel->runner();
+    return d->runner ? d->runner->id() : QString();
 }
 
-void ResultsModel::setRunner(const QString &runner)
+void ResultsModel::setRunner(const QString &runnerId)
 {
-    d->resultsModel->setRunner(runner);
+    if (runnerId == runner()) {
+        return;
+    }
+    if (runnerId.isEmpty()) {
+        d->runner = nullptr;
+    } else {
+        d->runner = runnerManager()->runner(runnerId);
+    }
+    Q_EMIT runnerChanged();
 }
 
 QString ResultsModel::runnerName() const
 {
-    return d->resultsModel->runnerName();
+    return d->runner ? d->runner->name() : QString();
 }
 
 QIcon ResultsModel::runnerIcon() const
 {
-    return d->resultsModel->runnerIcon();
+    return d->runner ? d->runner->icon() : QIcon();
 }
 
 QHash<int, QByteArray> ResultsModel::roleNames() const
@@ -425,6 +419,7 @@ QHash<int, QByteArray> ResultsModel::roleNames() const
     names[SubtextRole] = QByteArrayLiteral("subtext");
     names[DuplicateRole] = QByteArrayLiteral("isDuplicate");
     names[ActionsRole] = QByteArrayLiteral("actions");
+    names[MultiLineRole] = QByteArrayLiteral("multiLine");
     return names;
 }
 
